package com.bwie.auth.service.impl;


import com.alibaba.fastjson.JSON;
import com.bwie.auth.feign.UserFeign;
import com.bwie.auth.service.AuthService;
import com.bwie.common.constants.JwtConstants;
import com.bwie.common.domain.Admin;
import com.bwie.common.domain.Manager;
import com.bwie.common.domain.Student;
import com.bwie.common.domain.request.UserRequest;
import com.bwie.common.domain.response.JwtResponse;
import com.bwie.common.result.Result;
import com.bwie.common.utils.JwtUtils;
import org.apache.catalina.User;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;
import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.UUID;
import java.util.concurrent.TimeUnit;

/**
 * @ClassName AuthServiceImpl
 * @Description 描述
 * @Author LiAng.xiAo
 * @Date 2023/12/16 11:47
 */
@Service
public class AuthServiceImpl implements AuthService {

    @Autowired
    private UserFeign userFeign;
    @Autowired
    private HttpServletRequest request;
    @Autowired
    private StringRedisTemplate redisTemplate;
    /**
     * 功能描述
     *  三登录
     *      学生
     *      宿管
     *      管理
     * @author liguangyao
     * @Date 2023/12/17
     * @param userRequest
     * @return
     */
    @Override
    public Result<JwtResponse> login(UserRequest userRequest) {
        //学生1,宿管2,管理3,
        if(userRequest.getRank()==1){
            Result<Student> result=userFeign.StudentLogin(userRequest);
            if (result.getCode()==500){
                Result.error("登录失败");
            }
            Student data = result.getData();
            if(data!=null){
                //调用生成token的方法
                String token = getToken();
                //将用户存入到redis中15分钟
                redisTemplate.opsForValue().set(JwtConstants.USER_KEY+token, JSON.toJSONString(data),15, TimeUnit.MINUTES);
                JwtResponse jwtResponse = new JwtResponse(token,"15MIN");
                return Result.success(jwtResponse,"学生登录成功");
            }
            return Result.error("该用户不存在");
        }
        if(userRequest.getRank()==2){
            //feign调用
            Result<Manager> result=userFeign.ManagerLogin(userRequest);
            if (result.getCode()==500){
                Result.error("登录失败");
            }
            Manager data = result.getData();
            if(data!=null){
                //调用生成token的方法
                String token = getToken();
                //将用户存入到redis中15分钟
                redisTemplate.opsForValue().set(JwtConstants.USER_KEY+token, JSON.toJSONString(data),15, TimeUnit.MINUTES);
                JwtResponse jwtResponse = new JwtResponse(token,"15MIN");
                return Result.success(jwtResponse,"宿管登录成功");
            }
            return Result.error("该用户不存在");
        }
        if(userRequest.getRank()==3){
            Result<Admin> result=userFeign.AdminLogin(userRequest);
            if (result.getCode()==500){
                Result.error("登录失败");
            }
            Admin data = result.getData();
            if(data!=null){
                //调用生成token的方法
                String token = getToken();
                //将用户存入到redis中15分钟
                redisTemplate.opsForValue().set(JwtConstants.USER_KEY+token, JSON.toJSONString(data),15, TimeUnit.MINUTES);
                JwtResponse jwtResponse = new JwtResponse(token,"15MIN");
                return Result.success(jwtResponse,"管理登录成功");
            }
            //返回值为空
            return Result.error("该用户不存在");
        }
        //未选择登录等级
        return Result.error("请选择您登录等级");
    }



    //token生成
    private String getToken(){
        HashMap<String, Object> map = new HashMap<>();
        //生成一个uuid
        String useKey = UUID.randomUUID().toString().replaceAll("-","");
        map.put(JwtConstants.USER_KEY,useKey);
        //调用生成token的方法
        String token = JwtUtils.createToken(map);
        return token;
    }

}
